using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Input;

namespace colorsquare
{
	public class Avatar
	{
		private Texture2D texture;
		private int size = 18;
		private Point screen_location;
		public Rectangle bounds;
        public Vector2 offset = Vector2.Zero;

		private const float maxspeed = 20, minspeed = 0.1F, accel = 1.3F, drag = 0.93F;
		private Vector2 velocity = Vector2.Zero;

		public Avatar ()
		{
		}

		public void Initialize (Point init_location)
		{
			this.screen_location = init_location;
			bounds = new Rectangle (screen_location.X, screen_location.Y, size, size);
		}

		public void LoadContent (GraphicsDevice graphics_device)
		{
			texture = new Texture2D (graphics_device, 1, 1);
			texture.SetData<Color> (new Color[] { Color.Red });
		}

		public void Draw (SpriteBatch spriteBatch)
		{
			spriteBatch.Draw (texture,
			                  new Rectangle (screen_location.X, screen_location.Y, size, size),
			                  Color.White);
		}

		public void Update ()
		{
			update_velocity ();

            offset += velocity;

			bounds = new Rectangle (
				(int)(offset.X) + screen_location.X,
				(int)(offset.Y) + screen_location.Y,
				bounds.Width,
				bounds.Height);

		}
		
		private void update_velocity ()
		{
			KeyboardState keyboard_state = Keyboard.GetState ();

			velocity.X *= drag;
			velocity.Y *= drag;

			if (keyboard_state.IsKeyDown (Keys.Right)) {
				velocity.X += accel;
			} else if (keyboard_state.IsKeyDown (Keys.Left)) {
				velocity.X -= accel;
			}
			
			if (keyboard_state.IsKeyDown (Keys.Up)) {
				velocity.Y -= accel;
			} else if (keyboard_state.IsKeyDown (Keys.Down)) {
				velocity.Y += accel;
			}

			if (Math.Abs (velocity.X) < minspeed) {
				velocity.X = 0;
			} else {
				velocity.X = Math.Sign (velocity.X) * Math.Min (Math.Abs (velocity.X), maxspeed);
			}
			
			if (Math.Abs (velocity.Y) < minspeed) {
				velocity.Y = 0;
			} else {
				velocity.Y = Math.Sign (velocity.Y) * Math.Min (Math.Abs (velocity.Y), maxspeed);
			}
		}
	}

}

